@@ -7,6 +7,7 @@ from django.urls import path, reverse
 from django.utils.html import format_html
 
 from django_otp.conf import settings
+from django_otp.qr import write_qrcode_image
 
 from .models import HOTPDevice
 
@@ -17,10 +18,11 @@ class HOTPDeviceAdmin(admin.ModelAdmin):
     :class:`~django_otp.plugins.otp_hotp.models.HOTPDevice`.
     """
 
-    list_display = ['user', 'name', 'confirmed']
+    list_display = ['user', 'name', 'created_at', 'last_used_at', 'confirmed']
+    list_filter = ['created_at', 'last_used_at', 'confirmed']
 
     raw_id_fields = ['user']
-    readonly_fields = ['qrcode_link']
+    readonly_fields = ['created_at', 'last_used_at', 'qrcode_link']
     radio_fields = {'digits': admin.HORIZONTAL}
 
     def get_list_display(self, request):
@@ -43,6 +45,12 @@ class HOTPDeviceAdmin(admin.ModelAdmin):
                     'fields': ['user', 'name', 'confirmed'],
                 },
             ),
+            (
+                'Timestamps',
+                {
+                    'fields': ['created_at', 'last_used_at'],
+                },
+            ),
             (
                 'Configuration',
                 {
@@ -143,15 +151,9 @@ class HOTPDeviceAdmin(admin.ModelAdmin):
             raise PermissionDenied()
 
         try:
-            import qrcode
-            import qrcode.image.svg
-
-            img = qrcode.make(
-                device.config_url, image_factory=qrcode.image.svg.SvgImage
-            )
             response = HttpResponse(content_type='image/svg+xml')
-            img.save(response)
-        except ImportError:
+            write_qrcode_image(device.config_url, response)
+        except ModuleNotFoundError:
             response = HttpResponse('', status=503)
 
         return response
